#line 1 "inc/Test/Unit.pm - /usr/share/perl5/Test/Unit.pm"
#line 66

package Test::Unit;

use strict;
use vars qw($VERSION);

# NOTE: this version number has to be kept in sync with the
# number in the distribution file name (the distribution file
# is the tarball for CPAN release) because the CPAN module
# decides to fetch the tarball by looking at the version of
# this module if you say "install Test::Unit" in the CPAN
# shell.  "make tardist" should do this automatically.

$VERSION = '0.24';

1;
__END__
